@@ -57,7 +57,16 @@ class RespListSchema(RespBaseSchema):
     page_count: int = 0  # 总页数
     list: List[Dict] = None  # 数据list
 
-
+class RespListcountSchema(RespBaseSchema):
+    """
+    列表返回Schema
+    """
+    # page: int = 0  # 当前页码
+    # size: int = 0  # 每页大小
+    # count: int = 0  # 数据总条数
+    # page_count: int = 0  # 总页数
+    list: List[Dict] = None  # 数据list
+    
 class ListFilterSchema(BaseModel):
     """
     列表参数：过滤条件Schema
@@ -66,6 +75,16 @@ class ListFilterSchema(BaseModel):
     condition: str = None # 过滤条件
     value: str = None # 条件值，如condition为in或!in时，value为用“,”分割的多值得字符串
 
+class ListcountSchema(BaseModel):
+    """
+    列表参数：统计数据Schema
+    """
+
+    table:str = None
+    key: str = None # 字段名
+    condition: str = None # 过滤条件
+    value: str = None # 条件值，如condition为in或!in时，value为用“,”分割的多值得字符串
+
 
 class ListOrderSchema(BaseModel):
     """
@@ -96,6 +115,33 @@ class ListArgsSchema(BaseModel):
     orders: List[ListOrderSchema] = None  # 排序条件
     keys: List[ListKeySchema] = None  # 字段条件
 
+class ListcountOneSchema(BaseModel):
+
+    value: str = "None"  # 排序条件
+    filters: List[ListFilterSchema] = None  # 整体筛选
+    groups: List[ListcountSchema] = None  # 分组
+
+class ListArgsGroupSchema(BaseModel):
+    """
+    列表参数Schema 计数
+    """
+    # page: int = 1  # 当前页码
+    # size: int = 10  # 每页条数
+    # keywords: str = None  # 关键字，用于模糊、分词搜索
+    # is_deleted: str = None  # 软删标记
+    # user_id: int = None  # 数据对应用户id
+    # orders: List[ListOrderSchema] = None  # 排序条件
+    # keys: List[ListKeySchema] = None  # 字段条件
+    is_deleted:str = None
+    uuid:str = None
+    id:int = None
+    group:str 
+    
+    counts_data:List[ListcountOneSchema] = None
+
+
+
+
 
 class UserBaseSchema(BaseObjSchema):
     """
